==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/controller/osobniudajecontroller.php <==
<?php
/**
 * stanislav.elbl, 27.02.2016
 */

namespace RonPortal\Controller;

use Ron\DB\Database;
use Ron\DB\SQLUtils;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\Personalistika\NahlasenaZmena;
use RonPortal\NeniPravoException;
use RonPortal\Pomucky\VelikostiPomucekForm;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalDBRecord;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\RonPortalUtils;
use Ron\TextManager;
use RonPortal\System\FotoOutputObject;
use RonPortal\User;
use RonPortal\Zamestnanci\OsobniUdaje;

//require_once('adsapp/ronportalbrowser.php');
//require_once('pracovnipomery/zamestnanecpersonalni.php');
//require_once('pracovnipomery/zamestnanecmzdove.php');




class OsobniUdajeController extends HttpController
{
    /** @var  Database */
    var $database;

    /** @var  PravaNaOsoby */
    var $pravo_nahlaseni;

    /** @var  PravaNaOsoby */
    var $pravo_schvaleni;


    /**
     * OsobniUdajeController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
        Prava::nastavObdobiProPrava(time(),time());
        $this->pravo_nahlaseni = Prava::vratPrava('ou_zmeny_nahlaseni');
        $this->pravo_schvaleni = Prava::vratPrava('ou_zmeny_schval');

    }


    /**
     * @param $idPP
     * @return OsobniUdaje
     * @throws \Exception
     */
    function nactiOsobu($idPP)
    {
        $osoba = new OsobniUdaje();
        $osoba ->nactiZakladniUdaje($this ->database, $idPP);

        return $osoba;
    }


    /**
     * @param $idPP
     * @return FotoOutputObject
     * @throws \Exception
     */
    function downloadFoto($idPP)
    {
        if (!Prava::lzeZobrazitPP( [
            Prava::vratPrava('prohlizeni'),
            Prava::vratPrava('prohl_osobni') ], $idPP )
        ) {
            throw new NeniPravoException();
        }

        $result = new FotoOutputObject($this->database);
        $result->nactiIdFotkyPracovnihoPomeru($idPP);
        return $result;
    }


//    /**
//     * @return array
//     * @throws \Ron\DB\DBException
//     */
//    private function seznamTypuPPomucek()
//    {
//        $typyPomucek = [];
//        $params = $this->database->createParameters();
//
//        $sql = 'SELECT Kod, Popis, TypVelikosti FROM TypPomucky ORDER BY Popis';
//
//        $cursor = $this->database ->getSqlResult($sql, $params);
//        while ($row = $cursor->fetch()) {
//            $typyPomucek[] = $row;
//        }
//        $cursor->close();
//
//        return $typyPomucek;
//    }


//    /**
//     * @return array
//     * @throws \Ron\DB\DBException
//     */
//    public function velikostPomucekOsoby()
//    {
//        //Velikost pomucek osoby
//        $velikostPomucekOsoby = [];
//        $params = $this->database->createParameters();
//
//        $sql =
//            'SELECT VelikostPPomucky.TypVelikosti, VelikostPPomucky.Velikost, TypVelikosti.Popis ' .
//            'FROM TypVelikosti ' .
//            'JOIN VelikostPPomucky ON (TypVelikosti.Kod = VelikostPPomucky.TypVelikosti)' .
//            'LEFT JOIN VelikostPPOsoby ON (VelikostPPomucky.TypVelikosti = VelikostPPOsoby.TypVelikosti AND VelikostPPomucky.Velikost = VelikostPPOsoby.Velikost)' .
//            'WHERE RCOsoby = ' . $params ->addParameter(RonPortalSession::osobaRC());
//
//        MessageManager::addDebugLog($sql);
//
//        $cursor = $this->database ->getSqlResult($sql, $params);
//        while ($row = $cursor->fetch()) {
//            $velikostPomucekOsoby[] = $row;
//        }
//        $cursor->close();
//
//        return $velikostPomucekOsoby;
//    }


//    /**
//     * @return array
//     * @throws \Ron\DB\DBException
//     */
//    private function neprirazeneVelikosti()
//    {
//        $vsechnyVelikosti = $this->seznamVelikostiPomucek();
//        $prirazeneVelikost = $this->velikostPomucekOsoby();
//
//        $polePrirazenychVelikosti = [];
//        $cnt = 0;
//        foreach ($prirazeneVelikost as $item => $value){
//            $polePrirazenychVelikosti[$cnt][0] = $value[0];
//            $polePrirazenychVelikosti[$cnt][1] = $value[1];
//            $cnt++;
//        }
//
//        // pres odbc nefunguji parametry v EXISTS, a zrejme problem celkove s pod dotazy (ani count nefungoval - jako nahrada EXISTS) proto resim porovnanim poli
//        $neprirazeneVelikosti = array_map('unserialize', array_diff(array_map('serialize', $vsechnyVelikosti), array_map('serialize', $polePrirazenychVelikosti)));
//
//        return $neprirazeneVelikosti;
//    }


    /**
     * @param int $idpp
     * @return BaseViewObject
     * @throws \Exception
     * @throws \Ron\RonPortal\NeniPravoException
     */
    function detailOsobniVelikostPracovnichPomucek($idpp)
    {
        $editace = false;

        if (isset($_POST['cancel'])) {
            // uzivatel kliknul na Storno tlacitko
            return new Redirect(null, '?menuid=osobniudaje&osoba=' . $idpp);
        }

        if (isset($_POST['zapsatvelikosti'])  ||  isset($_POST['zapsatazpet'])) {
            // ulozeni hodnot - idpp nacte z postu
            $idpp = (int)$_POST['osoba'];
            $editace = true;
        }

        $pracovniPomer = PracovniPomer::nactiPP($this ->database, $idpp);

        Prava::nastavObdobiProPrava(time(), time());

        require_once 'person/nahlasenazmena.php';
        NahlasenaZmena::zkontrolujPravoNaZmenu('velikosti', $pracovniPomer ->rc, $editace);

        $form = new VelikostiPomucekForm($this ->database, $pracovniPomer);
        $form ->load();

        if ($editace) {
            try {
                $form->process();
                return new Redirect(null,
                    (isset($_POST['zapsatazpet'])
                        ? '?menuid=osobniudaje&osoba=' . $idpp
                        : '?menuid=osobniudaje&action=detailvelikostpomucek&osoba=' . $idpp)
                );
            } catch (\Exception $e) {
                MessageManager::addErrorMessage($e);
            }
        }

        return $form;

//        zruseno - je to tu nanic - stejne neobsahuje zadne podstatne informace
//        $historieNahlasenychZmenBrowser = new DriveNahlaseneZmenyBrowser($this->database, $pracovniPomer->idPP, 'velikostpomucek', null,'osobniudaje');
//        $historieNahlasenychZmenBrowser->showMessages = false;
//        $historieNahlasenychZmenBrowser->load();

//        return $historieNahlasenychZmenBrowser;
    }


    /**
     * @param PracovniPomer $pracovniPomer
     * @param $nahlaseneHodnoty
     * @param string $poznamka
     * @throws \Ron\DB\DBException
     */
    public function zapisNahlaseneZmeny($pracovniPomer, $nahlaseneHodnoty, $poznamka)
    {
        $rec = new RonPortalDBRecord($this ->database, 'NahlasenaZmena', $this);
        $rec ->addField('TypZmeny', '', false, 20, 'velikostpomucek');
        $rec ->addField('RC', '', false, 15, $pracovniPomer->rc);
        $rec ->addField('DatumCas', 'timestamp', false, 0, time());
        $rec ->addField('Hodnoty', 'memo', false, 0, $nahlaseneHodnoty);
        $rec ->addField('Nahlasil', '', false, 15, User::getRC());
        $rec ->addField('DatumCasZpracovani', 'timestamp', false, 0, time());
        $rec ->addField('Zpracoval', '', false, 15, User::getRC());
        $rec ->addField('Poznamka', 'memo', false, 0, $poznamka);

        $id = SQLUtils::newSerialNumber($this ->database, 'NahlasenaZmena', 'Id');
        $rec ->addField('Id', 'int', false, 0, $id);

        $rec ->insertRecord();

        MessageManager::addInfoMessage( \Ron\ronText('Hlaseni_ulozeno') );
    }

    /**
     * @param string $action
     * @return BaseViewObject|\Ron\MVC\InternalRedirect|\Ron\MVC\OutputObject|Redirect|\Ron\MVC\ViewObject|string
     * @throws \Ron\DB\DBException
     * @throws \Exception
     */
    public function handleAction($action)
    {
        TextManager::getInstance()->loadStrings('nahlasenezmeny.ini');
        TextManager::getInstance()->loadStrings('person.ini');
        HtmlHeaders::getInstance()->addScript('script/nahlasenezmeny.js');

        Prava::nastavObdobiProPrava(time(), time());
        //Prava::nactiPravaUzivatele($this ->database);

        if ( isset($_GET['foto']) ) {
            return $this ->downloadFoto((int)$_GET['foto']);
        }

        $pravaOsobni = Prava::vratPrava('prohl_osobni');
        $prava = [$pravaOsobni, Prava::vratPrava('prohlizeni')];

        $pravaNahlasit = Prava::vratPrava('ou_zmeny_nahlaseni');

        $ou_action = isset($_GET['action']) ? $_GET['action'] : '';

        switch ($ou_action) {
            case 'detailvelikostpomucek':
                //Formular pro upraveni osobnich velikosti
                return $this-> detailOsobniVelikostPracovnichPomucek((int)$_GET['osoba']);
        }


        $filterForm = new RonPortalFilterForm($this ->database, $action);
        $filterForm ->nastavPersonalistiku($prava);
        $filterForm ->nastavAkciGet('osobniudaje');
        $filterForm ->loadData();

        Model::addData('filterForm', $filterForm);

        $osoba = $this ->nactiOsobu($filterForm ->vybranaOsoba);

        if ($pravaOsobni ->lzeZobrazitPP($osoba ->idPP)) {
            // nacte dalsi osobni udaje
            Model::addData('zobrazitOsobni', true);
            Model::addData('nahlasitZmenu', $this->pravo_nahlaseni->lzeZobrazitRC($osoba ->rc));

            $osoba->nactiAdresy($this ->database);
            $osoba->nactiPrukazyOsoby($this->database);
            $osoba->nactiRodinnyStav($this ->database);
            $osoba->nactiZdravotniStav($this ->database);
            $osoba->nactiZdravotniPojistovnu($this ->database);
            $osoba->nactiVzdelani($this ->database);
            $osoba->nactiDovednosti($this ->database, true); // jen nejvyssi uroven
            $osoba->nactiPracovniMista($this ->database);
            $osoba->nactiUcetOsoby($this ->database);
            $osoba->nactiRodinnePrislusniky($this->database);
            $osoba->nactiEvidencniStavy($this->database);

            if (RonPortalUtils::jeNainstalovanaAplikace($this->database, 'MZDY')) {
                $osoba->nactiPenzijniPripojisteniOsoby($this->database);
                $osoba->nactiZivotniPojisteniOsoby($this->database);
            }

            $osoba ->nactiVelikostPracovnichPomucek($this ->database);
            $osoba ->seznamVydanychPracovnichPomucek($this ->database);
            $osoba ->seznamNesplnenychNarokuNaPracovniPomucky($this ->database);
        } else {
            Model::addData('zobrazitOsobni', false);
        }

        Model::addData('osoba', $osoba);

        return new BaseViewObject('ronportal/zamestnanci/view_osobni_udaje.php');
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2305_171.zip: ronportal/ronportal/controller/osobniudajecontroller.php <==
<?php
/**
 * stanislav.elbl, 27.02.2016
 */

namespace RonPortal\Controller;

use Ron\DB\Database;
use Ron\DB\SQLUtils;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use RonPortal\NeniPravoException;
use RonPortal\Pomucky\VelikostiPomucekForm;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalDBRecord;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\RonPortalUtils;
use Ron\TextManager;
use RonPortal\System\FotoOutputObject;
use RonPortal\User;
use RonPortal\Zamestnanci\NahlasenaZmena;
use RonPortal\Zamestnanci\OsobniUdaje;

//require_once('adsapp/ronportalbrowser.php');
//require_once('pracovnipomery/zamestnanecpersonalni.php');
//require_once('pracovnipomery/zamestnanecmzdove.php');




class OsobniUdajeController extends HttpController
{
    /** @var  Database */
    var $database;

    /** @var  PravaNaOsoby */
    var $pravo_nahlaseni;

    /** @var  PravaNaOsoby */
    var $pravo_schvaleni;


    /**
     * OsobniUdajeController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
        Prava::nastavObdobiProPrava(time(),time());
        $this->pravo_nahlaseni = Prava::vratPrava('ou_zmeny_nahlaseni');
        $this->pravo_schvaleni = Prava::vratPrava('ou_zmeny_schval');

    }


    /**
     * @param $idPP
     * @return OsobniUdaje
     * @throws \Exception
     */
    function nactiOsobu($idPP)
    {
        $osoba = new OsobniUdaje();
        $osoba ->nactiZakladniUdaje($this ->database, $idPP);

        return $osoba;
    }


    /**
     * @param $idPP
     * @return FotoOutputObject
     * @throws \Exception
     */
    function downloadFoto($idPP)
    {
        if (!Prava::lzeZobrazitPP( [
            Prava::vratPrava('prohlizeni'),
            Prava::vratPrava('prohl_osobni') ], $idPP )
        ) {
            throw new NeniPravoException();
        }

        $result = new FotoOutputObject($this->database);
        $result->nactiIdFotkyPracovnihoPomeru($idPP);
        return $result;
    }


//    /**
//     * @return array
//     * @throws \Ron\DB\DBException
//     */
//    private function seznamTypuPPomucek()
//    {
//        $typyPomucek = [];
//        $params = $this->database->createParameters();
//
//        $sql = 'SELECT Kod, Popis, TypVelikosti FROM TypPomucky ORDER BY Popis';
//
//        $cursor = $this->database ->getSqlResult($sql, $params);
//        while ($row = $cursor->fetch()) {
//            $typyPomucek[] = $row;
//        }
//        $cursor->close();
//
//        return $typyPomucek;
//    }


//    /**
//     * @return array
//     * @throws \Ron\DB\DBException
//     */
//    public function velikostPomucekOsoby()
//    {
//        //Velikost pomucek osoby
//        $velikostPomucekOsoby = [];
//        $params = $this->database->createParameters();
//
//        $sql =
//            'SELECT VelikostPPomucky.TypVelikosti, VelikostPPomucky.Velikost, TypVelikosti.Popis ' .
//            'FROM TypVelikosti ' .
//            'JOIN VelikostPPomucky ON (TypVelikosti.Kod = VelikostPPomucky.TypVelikosti)' .
//            'LEFT JOIN VelikostPPOsoby ON (VelikostPPomucky.TypVelikosti = VelikostPPOsoby.TypVelikosti AND VelikostPPomucky.Velikost = VelikostPPOsoby.Velikost)' .
//            'WHERE RCOsoby = ' . $params ->addParameter(RonPortalSession::osobaRC());
//
//        MessageManager::addDebugLog($sql);
//
//        $cursor = $this->database ->getSqlResult($sql, $params);
//        while ($row = $cursor->fetch()) {
//            $velikostPomucekOsoby[] = $row;
//        }
//        $cursor->close();
//
//        return $velikostPomucekOsoby;
//    }


//    /**
//     * @return array
//     * @throws \Ron\DB\DBException
//     */
//    private function neprirazeneVelikosti()
//    {
//        $vsechnyVelikosti = $this->seznamVelikostiPomucek();
//        $prirazeneVelikost = $this->velikostPomucekOsoby();
//
//        $polePrirazenychVelikosti = [];
//        $cnt = 0;
//        foreach ($prirazeneVelikost as $item => $value){
//            $polePrirazenychVelikosti[$cnt][0] = $value[0];
//            $polePrirazenychVelikosti[$cnt][1] = $value[1];
//            $cnt++;
//        }
//
//        // pres odbc nefunguji parametry v EXISTS, a zrejme problem celkove s pod dotazy (ani count nefungoval - jako nahrada EXISTS) proto resim porovnanim poli
//        $neprirazeneVelikosti = array_map('unserialize', array_diff(array_map('serialize', $vsechnyVelikosti), array_map('serialize', $polePrirazenychVelikosti)));
//
//        return $neprirazeneVelikosti;
//    }


    /**
     * @param int $idpp
     * @return BaseViewObject|Redirect
     * @throws \Exception
     * @throws \Ron\RonPortal\NeniPravoException
     */
    function detailOsobniVelikostPracovnichPomucek($idpp)
    {
        $editace = false;

        if (isset($_POST['cancel'])) {
            // uzivatel kliknul na Storno tlacitko
            return new Redirect(null, '?menuid=osobniudaje&osoba=' . $idpp);
        }

        if (isset($_POST['zapsatvelikosti'])  ||  isset($_POST['zapsatazpet'])) {
            // ulozeni hodnot - idpp nacte z postu
            $idpp = (int)$_POST['osoba'];
            $editace = true;
        }

        $pracovniPomer = PracovniPomer::nactiPP($this ->database, $idpp);

        Prava::nastavObdobiProPrava(time(), time());

        if (!NahlasenaZmena::jePravoNaZmenu('velikosti', $pracovniPomer ->rc, $editace)) {
            throw new NeniPravoException();
        }

        $form = new VelikostiPomucekForm($this ->database, $pracovniPomer);
        $form ->load();

        if ($editace) {
            try {
                $form->process();
                return new Redirect(null,
                    (isset($_POST['zapsatazpet'])
                        ? '?menuid=osobniudaje&osoba=' . $idpp
                        : '?menuid=osobniudaje&action=detailvelikostpomucek&osoba=' . $idpp)
                );
            } catch (\Exception $e) {
                MessageManager::addErrorMessage($e);
            }
        }

        return $form;

//        zruseno - je to tu nanic - stejne neobsahuje zadne podstatne informace
//        $historieNahlasenychZmenBrowser = new DriveNahlaseneZmenyBrowser($this->database, $pracovniPomer->idPP, 'velikostpomucek', null,'osobniudaje');
//        $historieNahlasenychZmenBrowser->showMessages = false;
//        $historieNahlasenychZmenBrowser->load();

//        return $historieNahlasenychZmenBrowser;
    }


    /**
     * @param PracovniPomer $pracovniPomer
     * @param $nahlaseneHodnoty
     * @param string $poznamka
     * @throws \Ron\DB\DBException
     */
    public function zapisNahlaseneZmeny($pracovniPomer, $nahlaseneHodnoty, $poznamka)
    {
        $rec = new RonPortalDBRecord($this ->database, 'NahlasenaZmena', $this);
        $rec ->addField('TypZmeny', '', false, 20, 'velikostpomucek');
        $rec ->addField('RC', '', false, 15, $pracovniPomer->rc);
        $rec ->addField('DatumCas', 'timestamp', false, 0, time());
        $rec ->addField('Hodnoty', 'memo', false, 0, $nahlaseneHodnoty);
        $rec ->addField('Nahlasil', '', false, 15, User::getRC());
        $rec ->addField('DatumCasZpracovani', 'timestamp', false, 0, time());
        $rec ->addField('Zpracoval', '', false, 15, User::getRC());
        $rec ->addField('Poznamka', 'memo', false, 0, $poznamka);

        $id = SQLUtils::newSerialNumber($this ->database, 'NahlasenaZmena', 'Id');
        $rec ->addField('Id', 'int', false, 0, $id);

        $rec ->insertRecord();

        MessageManager::addInfoMessage( \Ron\ronText('Hlaseni_ulozeno') );
    }




    /**
     * @param string $action
     * @return BaseViewObject|\Ron\MVC\InternalRedirect|\Ron\MVC\OutputObject|Redirect|\Ron\MVC\ViewObject|string
     * @throws \Ron\DB\DBException
     * @throws \Exception
     */
    public function handleAction($action)
    {
        TextManager::getInstance()->loadStrings('zamestnanci.ini');
        TextManager::getInstance()->loadStrings('nahlasenezmeny.ini'); // TODO: predelat a odstranit
        TextManager::getInstance()->loadStrings('person.ini');

        HtmlHeaders::getInstance()->setTitle( TextManager::_('RON_Portal') . ' - ' . TextManager::_('Osobni_udaje'));

        Prava::nastavObdobiProPrava(time(), time());
        //Prava::nactiPravaUzivatele($this ->database);

        if ( isset($_GET['foto']) ) {
            return $this ->downloadFoto((int)$_GET['foto']);
        }

        $pravaOsobni = Prava::vratPrava('prohl_osobni');
        $prava = [$pravaOsobni, Prava::vratPrava('prohlizeni')];

        //$pravaNahlasit = Prava::vratPrava('ou_zmeny_nahlaseni');

        $ou_action = isset($_GET['action']) ? $_GET['action'] : '';

        switch ($ou_action) {
            case 'detailvelikostpomucek':
                //Formular pro upraveni osobnich velikosti
                return $this-> detailOsobniVelikostPracovnichPomucek((int)$_GET['osoba']);
        }


        $filterForm = new RonPortalFilterForm($this ->database, $action);
        $filterForm ->nastavPersonalistiku($prava);
        $filterForm ->nastavAkciGet('osobniudaje');
        $filterForm ->loadData();

        Model::addData('filterForm', $filterForm);

        $osoba = $this ->nactiOsobu($filterForm ->vybranaOsoba);
        $nahlaseneZmeny = null;

        if ($pravaOsobni ->lzeZobrazitPP($osoba ->idPP)) {
            // nacte dalsi osobni udaje
            Model::addData('zobrazitOsobni', true);
            Model::addData('nahlasitZmenu', $this->pravo_nahlaseni->lzeZobrazitRC($osoba ->rc));

            $osoba->nactiAdresy($this ->database);
            $osoba->nactiPrukazyOsoby($this->database);
            $osoba->nactiRodinnyStav($this ->database);
            $osoba->nactiZdravotniStav($this ->database);
            $osoba->nactiZdravotniPojistovnu($this ->database);
            $osoba->nactiVzdelani($this ->database);
            $osoba->nactiDovednosti($this ->database, true); // jen nejvyssi uroven
            $osoba->nactiPracovniMista($this ->database);
            $osoba->nactiUcetOsoby($this ->database);
            $osoba->nactiRodinnePrislusniky($this->database);
            $osoba->nactiEvidencniStavy($this->database);

            if (RonPortalUtils::jeNainstalovanaAplikace($this->database, 'MZDY')) {
                $osoba->nactiPenzijniPripojisteniOsoby($this->database);
                $osoba->nactiZivotniPojisteniOsoby($this->database);
            }

            $osoba ->nactiVelikostPracovnichPomucek($this ->database);
            $osoba ->seznamVydanychPracovnichPomucek($this ->database);
            $osoba ->seznamNesplnenychNarokuNaPracovniPomucky($this ->database);

            $this->pravo_nahlaseni = Prava::vratPrava('ou_zmeny_nahlaseni');
            $this->pravo_schvaleni = Prava::vratPrava('ou_zmeny_schval');

            if ($this ->pravo_nahlaseni ->lzeZobrazitRC($osoba ->rc)  ||  $this ->pravo_schvaleni ->lzeZobrazitRC($osoba ->rc)) {
                $nahlaseneZmeny = \RonPortal\Zamestnanci\NahlasenaZmena::nactiZmeny($this->database, $osoba->rc, true);
            }
        } else {
            Model::addData('zobrazitOsobni', false);
        }

        Model::addData('osoba', $osoba);
        Model::addData('nahlaseneZmeny', $nahlaseneZmeny);

        return new BaseViewObject('ronportal/zamestnanci/view_osobni_udaje.php');
    }
}
